@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   <http://www.gnu.org/licenses/>.
+   see <http://www.gnu.org/licenses/>.
 
    Author: Stef Walter <stef@memberwebs.com>
 */
@@ -655,8 +655,8 @@ memcpy_with_vbits (void *dest,
 
 #ifdef WITH_VALGRIND
 	if (vbits_setup == 1) {
-		VALGRIND_SET_VBITS (dest, vbits, length);
-		VALGRIND_SET_VBITS (src, vbits, length);
+		(void)VALGRIND_SET_VBITS (dest, vbits, length);
+		(void)VALGRIND_SET_VBITS (src, vbits, length);
 	}
 	free (vbits);
 #endif
@@ -885,6 +885,19 @@ sec_acquire_pages (size_t *sz,
 
 	DEBUG_ALLOC ("gkr-secure-memory: new block ", *sz);
 
+#if defined(MADV_DONTDUMP)
+	if (madvise (pages, *sz, MADV_DONTDUMP) < 0) {
+		if (show_warning && egg_secure_warnings) {
+			/*
+			 * Not fatal - this was added in Linux 3.4 and older
+			 * kernels will legitimately fail this at runtime
+			 */
+			fprintf (stderr, "couldn't MADV_DONTDUMP %lu bytes of memory (%s): %s\n",
+				 (unsigned long)*sz, during_tag, strerror (errno));
+		}
+	}
+#endif
+
 	show_warning = 1;
 	return pages;
 
@@ -1299,7 +1312,7 @@ egg_secure_records (unsigned int *count)
 			if (records == NULL)
 				break;
 
-			/* Make sure this actualy accounts for all memory */
+			/* Make sure this actually accounts for all memory */
 			ASSERT (total == block->n_words);
 		}
 
