@@ -52,7 +52,7 @@ static GQuark OID_ANSI_SECP521R1;
 static void
 init_quarks (void)
 {
-	static volatile gsize quarks_inited = 0;
+	static gsize quarks_inited = 0;
 
 	if (g_once_init_enter (&quarks_inited)) {
 
