@@ -14,9 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -292,7 +291,7 @@ factory_create_collection (GkmSession *session, GkmTransaction *transaction,
 		if (collection != NULL) {
 			gkm_session_complete_object_creation (session, transaction, GKM_OBJECT (collection),
 			                                      FALSE, attrs, n_attrs);
-			return g_object_ref (collection);
+			return GKM_OBJECT (g_object_ref (collection));
 		}
 	}
 
